@@ -19,30 +19,26 @@
 # along with Total Open Station.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-
-def to_dat(e):
-    if e[4].endswith("R"):
-        string = "%s %s %s %s\r\n" % (e[0], e[0], e[1], e[2])
-        return string
-    else:
-        return ''
+from . import Builder
 
 
-class OutputFormat:
+def to_dat(point):
+    result = "{p.id} {p.id} {p.geometry.x} {p.geometry.y}\r\n".format(p=point)
+    return result
+
+
+class OutputFormat(Builder):
 
     """
     Exports points data in DAT format suitable for use with Archis.
 
-    ``data`` should be an iterable (e.g. list) containing one iterable (e.g.
-    tuple) for each point. The default order is PID, x, x, z, TEXT.
-
-    This is consistent with our current standard.
+    ``data`` must be an iterable containing Feature objects.
     """
 
     def __init__(self, data):
         self.data = data
 
     def process(self):
-        lines = [to_dat(e) for e in self.data]
+        lines = [to_dat(point) for point in self.data]
         output = "".join(lines)
         return output
