@@ -18,39 +18,20 @@
 # along with Total Open Station.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-import geojson
+import json
+
+from totalopenstation.formats import FeatureCollection
+
+from . import Builder
 
 
-def output_geojson(data):
+class OutputFormat(Builder):
     '''A GeoJSON output driver.'''
 
-    fs = []
-
-    for point in data:
-        pid, x, y, z, text = point
-        x, y, z = [float(c) for c in x, y, z]
-        p = geojson.Point([x, y, z])
-        prop = dict(text=text)
-        f = geojson.Feature(id=pid, geometry=p, properties=prop)
-        fs.append(f)
-    fc = geojson.FeatureCollection(fs)
-    return geojson.dumps(fc)
-
-
-class TotalOpenGEOJSON:
-    '''A GeoJSON output driver.
-
-    Depends on the geojson package http://pypi.python.org/pypi/geojson/
-
-    FIXME This is an example of how classes are probably useless for
-    coding output formats. A transition towards an eventual new
-    structure could be done in 2 passages, the first being making the
-    current classes empty wrappers around a function.'''
-
     def __init__(self, data):
 
-        self.data = data
+        self.feature_collection = FeatureCollection(data)
 
     def process(self):
 
-        return output_geojson(self.data)
+        return json.dumps(self.feature_collection.__geo_interface__)
